@@ -1,6 +1,6 @@
 from collections import defaultdict, deque, namedtuple
 from dataclasses import is_dataclass
-from datetime import datetime, time, date
+from datetime import datetime, time, date, timedelta
 from decimal import Decimal
 from enum import Enum
 from typing import (
@@ -23,16 +23,16 @@ from .errors import ParseError, MissingFields, UnknownJSONKey, MissingData
 from .log import LOG
 from .parsers import *
 from .type_def import (
-    ExplicitNull, PyForwardRef, FrozenKeys, DefFactory, NoneType, JSONObject,
+    ExplicitNull, FrozenKeys, DefFactory, NoneType, JSONObject,
     M, N, T, E, U, DD, LSQ, NT
 )
 from .utils.string_conv import to_snake_case
 from .utils.type_conv import (
-    as_bool, as_str, as_datetime, as_date, as_time, as_int
+    as_bool, as_str, as_datetime, as_date, as_time, as_int, as_timedelta
 )
 from .utils.typing_compat import (
     is_literal, is_typed_dict, get_origin, get_args, is_annotated,
-    eval_forward_ref
+    eval_forward_ref_if_needed
 )
 
 
@@ -225,11 +225,19 @@ class LoadMixin(AbstractLoader, BaseLoadHook):
         # alias: as_date
         ...
 
+    @staticmethod
+    @_alias(as_timedelta)
+    def load_to_timedelta(
+            o: Union[str, N], base_type: Type[timedelta]) -> timedelta:
+        # alias: as_timedelta
+        ...
+
     @classmethod
     def get_parser_for_annotation(cls, ann_type: Type[T],
                                   base_cls: Type[T] = None) -> AbstractParser:
         """Returns the Parser (dispatcher) for a given annotation type."""
         hooks = cls.__LOAD_HOOKS__
+        ann_type = eval_forward_ref_if_needed(ann_type, base_cls)
         load_hook = hooks.get(ann_type)
         base_type = ann_type
 
@@ -274,7 +282,7 @@ class LoadMixin(AbstractLoader, BaseLoadHook):
                     elif issubclass(base_type, tuple) \
                             and hasattr(base_type, '_fields'):
 
-                        if hasattr(base_type, '__annotations__'):
+                        if getattr(base_type, '__annotations__', None):
                             # Annotated as a `typing.NamedTuple` subtype
                             load_hook = hooks.get(NamedTupleMeta)
                             return NamedTupleParser(
@@ -299,12 +307,6 @@ class LoadMixin(AbstractLoader, BaseLoadHook):
                 elif base_type is Any:
                     load_hook = cls.default_load_to
 
-                elif isinstance(base_type, (str, PyForwardRef)):
-                    # Evaluate the forward reference here.
-                    base_type = eval_forward_ref(base_type, base_cls)
-
-                    return cls.get_parser_for_annotation(base_type, base_cls)
-
                 elif base_type is Ellipsis:
                     load_hook = cls.default_load_to
 
@@ -459,6 +461,7 @@ def setup_default_loader(cls=LoadMixin):
     cls.register_load_hook(datetime, cls.load_to_datetime)
     cls.register_load_hook(time, cls.load_to_time)
     cls.register_load_hook(date, cls.load_to_date)
+    cls.register_load_hook(timedelta, cls.load_to_timedelta)
 
 
 def get_loader(class_or_instance=None, create=False) -> Type[LoadMixin]:
