@@ -12,15 +12,17 @@ __all__ = [
     'is_generic',
     'is_base_generic',
     'is_annotated',
-    'eval_forward_ref'
+    'eval_forward_ref',
+    'eval_forward_ref_if_needed'
 ]
 
 import sys
+import types
 import typing
 from collections.abc import Callable
 
 from ..constants import PY36, PY38, PY310_OR_ABOVE
-from ..type_def import PyLiteral, PyTypedDicts, PyForwardRef
+from ..type_def import FREF, PyLiteral, PyTypedDicts, PyForwardRef
 
 
 # TODO maybe move this to `type_def` if it makes sense
@@ -100,21 +102,33 @@ if not PY36:    # pragma: no cover
         except AttributeError:
             return False
 
-    def _get_origin(cls, raise_=False):
-        try:
-            return cls.__origin__
-        except AttributeError:
-            if raise_:
-                raise
-            return cls
-
     # Ref:
     #   https://github.com/python/typing/blob/master/typing_extensions/src_py3/typing_extensions.py#L2111
     if PY310_OR_ABOVE:
         _get_args = typing.get_args
+
+        def _get_origin(cls, raise_=False):
+            if isinstance(cls, types.UnionType):
+                return typing.Union
+
+            try:
+                return cls.__origin__
+            except AttributeError:
+                if raise_:
+                    raise
+                return cls
+
     else:
         from typing_extensions import get_args as _get_args
 
+        def _get_origin(cls, raise_=False):
+            try:
+                return cls.__origin__
+            except AttributeError:
+                if raise_:
+                    raise
+                return cls
+
 
     def _get_named_tuple_field_types(cls, raise_=True):
         """
@@ -294,7 +308,7 @@ def is_annotated(cls):
 
 # Note: need to wrap the annotation for `base_type` with a forward ref,
 # because Python 3.6 complains.
-def eval_forward_ref(base_type: 'typing.Union[str, PyForwardRef]',
+def eval_forward_ref(base_type: FREF,
                      cls: typing.Type):
     """
     Evaluate a forward reference using the class globals, and return the
@@ -309,3 +323,17 @@ def eval_forward_ref(base_type: 'typing.Union[str, PyForwardRef]',
 
     # noinspection PyProtectedMember
     return typing._eval_type(base_type, base_globals, None)
+
+
+def eval_forward_ref_if_needed(base_type: FREF,
+                               base_cls: typing.Type):
+    """
+    If needed, evaluate a forward reference using the class globals, and
+    return the underlying type reference.
+    """
+
+    if isinstance(base_type, FREF.__constraints__):
+        # Evaluate the forward reference here.
+        base_type = eval_forward_ref(base_type, base_cls)
+
+    return base_type
